==> matrix_sdk-0.1.9.tar.gz: lib/src/event/room/state/avatar_change_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/matrix_sdk.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';

class AvatarChangeEvent extends StateEvent {
  static const String type = 'm.room.avatar';

  @override
  final String _type = type;

  /// An `mxc` url pointing to the avatar.
  final Uri url;

  AvatarChangeEvent(
      this.url, EventId id, RoomId roomId, UserId senderId, DateTime time)
      : super(id, roomId, senderId, time, stateKey: '', );

  factory AvatarChangeEvent.fromJson(
      EventId id,RoomId roomId, UserId sender,
      DateTime time, dynamic json) {
    var url = json['content']['url'];
    return AvatarChangeEvent(Uri.parse(url), id, roomId, sender, time);
  }

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'content': {'url': url.toString()}
    });
}

==> matrix_sdk-0.2.0.tar.gz: lib/src/event/room/state/avatar_change_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/user.dart';

class AvatarChangeEvent extends StateEvent {
  static const String type = 'm.room.avatar';

  @override
  final String matrixType = type;

  /// An `mxc` url pointing to the avatar.
  final Uri url;

  AvatarChangeEvent(
      this.url, EventId id, Room room, User sender, DateTime time)
      : super(id, room, sender, time, stateKey: '', );

  factory AvatarChangeEvent.fromJson(
      EventId id,Room room, User sender,
      DateTime time, dynamic json) {
    var url = json['content']['url'];
    return AvatarChangeEvent(Uri.parse(url), id, room, sender, time);
  }

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'content': {'url': url.toString()}
    });
}
